@@ -28,6 +28,7 @@
 
 #define VOLUME 4000 /* out of 1 << 15 */
 #define FILTER_KERNEL_LEN 51
+#define OVERSAMPLE_FACTOR 25
 
 // The following values give the cutoff range for our band-pass
 // filter. These frequencies come from a frequency analysis of
@@ -177,18 +178,34 @@ static void AddFilters(struct filter *f1, struct filter *f2)
 }
 
 // square wave function for sound generation
-static inline float square_wave(float time)
+static inline float SquareWave(float time)
 {
 	int l = (int) time;
 	return time - l < 0.5 ? -0.5 : 0.5;
 }
 
+static float OversampledSquareWave(int i)
+{
+	float presample;
+	int j;
+
+	// Sample the square wave at close to TIMER_FREQ and downsample
+	// using a simple low-pass filter. This reduces aliasing artifacts.
+	presample = 0;
+	for (j = 0; j < OVERSAMPLE_FACTOR; j++) {
+		float t = i + ((float) j) / OVERSAMPLE_FACTOR;
+		t = (t * current_freq) / output_freq;
+		presample += SquareWave(t);
+	}
+	return presample / ((float) OVERSAMPLE_FACTOR);
+}
+
 // callback function to generate sound
 static void snd_callback(void *userdata, Uint8 *stream8, int len)
 {
 	static int lasttime;
 	static float lastfreq;
-	uint16_t *stream = (uint16_t *) stream8;
+	int16_t *stream = (int16_t *) stream8;
 	float sample;
 	int i;
 
@@ -209,11 +226,11 @@ static void snd_callback(void *userdata, Uint8 *stream8, int len)
 		if (!speaker_on) {
 			sample = 0;
 		} else {
-			sample = square_wave(current_freq * (i + lasttime)
-			                   / output_freq);
+			sample = OversampledSquareWave(i + lasttime);
 		}
+
 		sample = FilterNext(&tinny_filter, sample);
-		stream[i] = (1 << 15) + (signed int) (sample * VOLUME);
+		stream[i] = (signed int) (sample * VOLUME);
 	}
 
 	lasttime += len;
@@ -307,7 +324,7 @@ void Speaker_Init(void)
 
 	audiospec.samples = 1024;
 	audiospec.freq = 48000;
-	audiospec.format = AUDIO_U16SYS;
+	audiospec.format = AUDIO_S16SYS;
 	audiospec.channels = 1;
 	audiospec.callback = &snd_callback;
 
