@@ -115,6 +115,7 @@ static SDL_Texture *texture_upscaled = NULL;
 #define ICON_SCALE 4
 static SDL_Surface *surface_from_sopsym(sopsym_t *sym)
 {
+	SDL_Color *pal = VideoPalettes[0].color;
 	SDL_Surface *surface = SDL_CreateRGBSurface(
 		0, sym->w * ICON_SCALE, sym->h * ICON_SCALE, 32,
 		0xff000000, 0x00ff0000, 0x0000ff00, 0x000000ff);
@@ -143,7 +144,7 @@ static SDL_Surface *surface_from_sopsym(sopsym_t *sym)
 				dst[x] = 0;
 				continue;
 			}
-			p = &cga_pal[src[sx]];
+			p = &pal[src[sx]];
 			dst[x] = (p->r << 24) | (p->g << 16)
 			       | (p->b << 8) | 0xff;
 		}
@@ -216,9 +217,9 @@ static void set_icon(void)
 	sopsym_t *sym;
 
 	if (is_special_day()) {
-		sym = symbol_plane[1][0];
+		sym = &symbol_plane[0]->sym[4];
 	} else {
-		sym = symbol_plane[0][0];
+		sym = &symbol_plane[0]->sym[0];
 	}
 
 	icon = surface_from_sopsym(sym);
@@ -652,14 +653,20 @@ static void getevents(void)
 		case SDL_KEYDOWN:
 			if (CtrlDown()) {
 				CtrlKeyPress(event.key.keysym.sym);
-			} else if (AltDown() && event.key.keysym.sym == SDLK_RETURN) {
+			} else if (AltDown() && (event.key.keysym.sym == SDLK_RETURN
+			                      || event.key.keysym.sym == SDLK_KP_ENTER)) {
 #ifndef NO_FULLSCREEN
 				vid_fullscreen = !vid_fullscreen;
 				Vid_Reset();
 				continue;
 #endif
-			}
-			if (!SDL_IsTextInputActive()
+			} else if (event.key.keysym.sym == SDLK_KP_ENTER && SDL_IsTextInputActive()) {
+				SDL_Keysym fake = {0};
+				fake.sym = '\n';
+				fake.scancode = SDL_SCANCODE_UNKNOWN;
+				input_buffer_push(fake);
+				continue;
+			} else if (!SDL_IsTextInputActive()
 			 || IsSpecialKey(&event.key.keysym)) {
 				input_buffer_push(event.key.keysym);
 			}
@@ -681,7 +688,7 @@ static void getevents(void)
 		case SDL_TEXTINPUT:
 			for (i = 0; event.text.text[i] != '\0'; ++i) {
 				char c = event.text.text[i];
-				SDL_Keysym fake;
+				SDL_Keysym fake = {0};
 				if (c >= 0x80) {
 					continue;
 				}
