@@ -15,6 +15,10 @@
 
 #include "sw.h"
 
-extern GAMES original_level;
+extern const GAMES original_level;
+extern GAMES custom_level;
+extern bool have_custom_level;
+
+void load_custom_level(const char *filename);
 
 #endif
