@@ -26,6 +26,7 @@
 #include "swasynio.h"
 #include "swconf.h"
 #include "swdisp.h"
+#include "swgrpha.h"
 #include "swinit.h"
 #include "swgames.h"
 #include "swmain.h"
@@ -39,7 +40,7 @@
 static const original_ob_t *orig_planes[MAX_PLYR * 2];
 GRNDTYPE *ground;
 
-static int have_savescore = 0;
+static bool have_savescore = false;
 static score_t savescore;		/* save players score on restart  */
 int starting_level = 0;
 
@@ -113,6 +114,11 @@ void initdisp(bool reset)
 static void initscore(score_t *score)
 {
 	memset(score, 0, sizeof(score_t));
+
+	if (have_savescore) {
+		*score = savescore;
+		have_savescore = false;
+	}
 }
 
 static void initflightscore(flight_score_t *score)
@@ -266,7 +272,7 @@ OBJECTS *initpln(OBJECTS * obp)
 	ob->ob_target = ob->ob_missiletarget = NULL;
 	ob->ob_firing = ob->ob_mfiring = NULL;
 	ob->ob_bombing = ob->ob_bfiring = ob->ob_home = false;
-	ob->ob_newsym = symbol_plane[ob->ob_orient][0];
+	ob->ob_newsym = &symbol_plane[0]->sym[ob->ob_orient ? 4 : 0];
 	ob->ob_athome = true;
 	ob->ob_onmap = true;
 	ob->ob_flightscore.combatwound = false;
@@ -285,8 +291,7 @@ OBJECTS *initpln(OBJECTS * obp)
 		ob->ob_target = NULL;
 		insertx(ob, &topobj);
 	} else {
-		deletex(ob);
-		insertx(ob, ob->ob_xnext);
+		insertx(ob, deletex(ob));
 	}
 
 	ob->ob_state = FLYING;
@@ -467,7 +472,7 @@ void initbomb(OBJECTS *obo)
 	ob->ob_life = BOMBLIFE;
 	ob->ob_owner = obo;
 	ob->ob_clr = obo->ob_clr;
-	ob->ob_newsym = symbol_bomb[0];
+	ob->ob_newsym = &symbol_bomb[0]->sym[0];
 	ob->ob_drawf = dispbomb;
 	ob->ob_movef = movebomb;
 
@@ -510,7 +515,7 @@ void initmiss(OBJECTS *obo)
 	ob->ob_life = MISSLIFE;
 	ob->ob_owner = obo;
 	ob->ob_clr = obo->ob_clr;
-	ob->ob_newsym = symbol_missile[0];
+	ob->ob_newsym = &symbol_missile[0]->sym[0];
 	ob->ob_drawf = NULL;
 	ob->ob_movef = movemiss;
 	ob->ob_missiletarget = obo->ob_mfiring;
@@ -564,7 +569,7 @@ void initburst(OBJECTS *obo)
 	ob->ob_life = BURSTLIFE;
 	ob->ob_owner = obo;
 	ob->ob_clr = obo->ob_clr;
-	ob->ob_newsym = symbol_burst[0];
+	ob->ob_newsym = &symbol_burst[0]->sym[0];
 	ob->ob_drawf = NULL;
 	ob->ob_movef = moveburst;
 
@@ -641,7 +646,7 @@ static OBJECTS *inittarget(const original_ob_t *orig_ob)
 			break;
 	}
 	ob->ob_clr = ob->ob_owner->ob_clr;
-	ob->ob_newsym = symbol_targets[0];
+	ob->ob_newsym = &symbol_targets[0]->sym[0];
 	ob->ob_drawf = disptarg;
 	ob->ob_movef = movetarg;
 	ob->ob_onmap = true;
@@ -718,7 +723,7 @@ void initexpl(OBJECTS *obo, int small)
 		ob->ob_lx = ob->ob_ly = ob->ob_hitcount = ob->ob_speed = 0;
 		ob->ob_owner = obo;
 		ob->ob_clr = oboclr;
-		ob->ob_newsym = symbol_debris[0];
+		ob->ob_newsym = &symbol_debris[0]->sym[0];
 		ob->ob_drawf = dispexpl;
 		ob->ob_movef = moveexpl;
 
@@ -780,7 +785,7 @@ static OBJECTS *initflock(const original_ob_t *orig_ob)
 	ob->ob_orient = 0;
 	ob->ob_life = FLOCKLIFE;
 	ob->ob_owner = ob;
-	ob->ob_newsym = symbol_flock[0];
+	ob->ob_newsym = &symbol_flock[0]->sym[0];
 	ob->ob_drawf = NULL;
 	ob->ob_movef = moveflck;
 	ob->ob_clr = 1;
@@ -818,7 +823,7 @@ void initbird(OBJECTS *obo, int i)
 	    0;
 	ob->ob_life = BIRDLIFE;
 	ob->ob_owner = obo;
-	ob->ob_newsym = symbol_bird[0];
+	ob->ob_newsym = &symbol_bird[0]->sym[0];
 	ob->ob_drawf = NULL;
 	ob->ob_movef = movebird;
 	ob->ob_clr = obo->ob_clr;
@@ -847,7 +852,7 @@ static OBJECTS *initox(const original_ob_t *orig_ob)
 	ob->ob_orient = ob->ob_lx = ob->ob_ly = ob->ob_ldx =
 	    ob->ob_ldy = ob->ob_dx = ob->ob_dy = 0;
 	ob->ob_owner = ob;
-	ob->ob_newsym = symbol_ox[0];
+	ob->ob_newsym = &symbol_ox[0]->sym[orig_ob->transform];
 	ob->ob_drawf = NULL;
 	ob->ob_movef = moveox;
 	ob->ob_clr = 1;
@@ -987,11 +992,14 @@ void swrestart(void)
 
 		get_endlevel(ob);
 
+		// Count down the remaining lives; the player gets awarded
+		// extra points for each life.
 		while (ob->ob_crashcnt < maxcrash) {
 			++ob->ob_crashcnt;
 			inc += 25;
 			ob->ob_score.score += inc;
 
+			swdisp();
 			Vid_Update();
 			
 			time = Timer_GetMS();
@@ -999,12 +1007,12 @@ void swrestart(void)
 		}
 		++gamenum;
 		savescore = ob->ob_score;
-		have_savescore = 1;
+		have_savescore = true;
 	} else {
 		// gamenum = 0;
 		// allow variable start level -- Jesse
 		gamenum = starting_level;
-		have_savescore = 0;
+		have_savescore = false;
 
 		// sh 28/10/2001: go back to the title screen
 
