@@ -37,8 +37,10 @@ bool conf_harrykeys = 0;            // plane rotation relative to screen
 bool conf_medals = 1;
 bool conf_big_explosions = 1;       // big oil tank explosions
 
+int conf_video_palette = 0;			// Video palette selection (0 is the default CGA color scheme)
+
 playmode_t playmode;		/* Mode of play                     */
-GAMES *currgame;		/* Game parameters and current game */
+const GAMES *currgame;		/* Game parameters and current game */
 OBJECTS *consoleplayer;
 int numtarg[2];			/* Number of active targets by color */
 int countmove;			/* Performance counters             */
@@ -52,8 +54,9 @@ bool soundflg = 0;		/* Sound flag                       */
 
 int displx;			/* Display left and right           */
 
-OBJECTS *nobjects;		/* Objects list.                    */
-OBJECTS oobjects[MAX_PLYR];	/* Original plane object description */
+OBJECTS *planes[MAX_PLYR];      /* Plane objects                    */
+int num_planes;
+
 OBJECTS *objbot, *objtop,	/* Top and bottom of object list    */
 *objfree,			/* Free list                        */
 *deltop, *delbot;		/* Newly deallocated objects        */
@@ -69,17 +72,15 @@ int keydelay = -1;		/* Number of displays per keystroke */
 int dispcnt;			/* Displays to delay keyboard       */
 int endstat;			/* End of game status for curr. move */
 int maxcrash;			/* Maximum number of crashes        */
+bool restart_flag;              /* Return to main menu              */
 
-int sintab[ANGLES] = {		/* sine table of pi/8 increments    */
+const int sintab[ANGLES] = {	/* sine table of pi/8 increments    */
 	0, 98, 181, 237,	/*   multiplied by 256              */
 	256, 237, 181, 98,
 	0, -98, -181, -237,
 	-256, -237, -181, -98
 };
 
-jmp_buf envrestart;		/* Restart environment for restart  */
-				/*  long jump.                      */
-
 /* player commands */
 
 /* buffer of player commands, loops round.
@@ -194,10 +195,10 @@ int swmain(int argc, char *argv[])
 {
 	int nexttic;
 
-	nobjects = (OBJECTS *) malloc(100 * sizeof(OBJECTS));
-
 	swinit(argc, argv);
-	setjmp(envrestart);
+
+restart:
+        restart_flag = false;
 
 	// sdh 28/10/2001: playmode is called from here now
 	// makes for a more coherent progression through the setup process
@@ -213,6 +214,11 @@ int swmain(int argc, char *argv[])
 	for (;;) {
 		int nowtime;
 
+		/* Sure, goto is bad, but this used to be a longjmp! */
+		if (restart_flag) {
+			goto restart;
+		}
+
 		/* generate a new move command periodically
 		 * and send to other players if necessary */
 
