@@ -30,10 +30,11 @@ extern bool conf_animals;
 extern bool conf_harrykeys;
 extern bool conf_medals;
 extern bool conf_big_explosions;
+extern int conf_video_palette;
 
 extern OBJECTS *consoleplayer;
 extern playmode_t playmode;
-extern GAMES   *currgame;
+extern const GAMES *currgame;
 extern int     numtarg[2];
 extern int     counttick, countmove;
 extern int     gamenum;
@@ -43,8 +44,8 @@ extern int     targrnge;
 extern bool    titleflg;
 extern bool    soundflg;
 extern int     displx;
-extern OBJECTS *nobjects;
-extern OBJECTS oobjects[MAX_PLYR];
+extern OBJECTS *planes[MAX_PLYR];
+extern int     num_planes;
 extern OBJECTS *objbot, *objtop, *objfree, *deltop, *delbot;
 extern OBJECTS topobj, botobj;
 extern OBJECTS *objsmax;
@@ -59,7 +60,7 @@ extern int     keydelay;
 extern int     dispcnt;
 extern int     endstat;
 extern int     maxcrash;
-extern jmp_buf envrestart;
+extern bool    restart_flag;
 
 extern int latest_player_commands[MAX_PLYR][MAX_NET_LAG];
 extern int latest_player_time[MAX_PLYR];
