@@ -613,13 +613,18 @@ static bool movepln(OBJECTS *ob)
 	}
 
 	if (ob->ob_endsts == WINNER && ob->ob_goingsun) {
-		ob->ob_newsym = symbol_plane_win[endcount / 18];
+		ob->ob_newsym = &symbol_plane_win[endcount / 18]->sym[0];
 	} else if (ob->ob_state == FINISHED) {
 		ob->ob_newsym = NULL;
 	} else if (ob->ob_state == FALLING && !ob->ob_dx && ob->ob_dy < 0) {
-		ob->ob_newsym = symbol_plane_hit[ob->ob_orient];
+		ob->ob_newsym = &symbol_plane_hit[ob->ob_orient]->sym[0];
+	} else if (ob->ob_orient) {
+		// Flipped:
+		int a = (16 - ob->ob_angle) % 16;
+		ob->ob_newsym = &symbol_plane[a % 4]->sym[4 + a / 4];
 	} else {
-		ob->ob_newsym = symbol_plane[ob->ob_orient][ob->ob_angle];
+		ob->ob_newsym = &symbol_plane[ob->ob_angle % 4]
+			->sym[ob->ob_angle / 4];
 	}
 
 	//ob->ob_newsym =
@@ -633,8 +638,10 @@ static bool movepln(OBJECTS *ob)
 
 	if (x < 0) {
 		x = ob->ob_x = 0;
+		updateobjpos(ob);
 	} else if (x >= (currgame->gm_max_x - 16)) {
 		x = ob->ob_x = currgame->gm_max_x - 16;
+		updateobjpos(ob);
 	}
 
 	if (!compplane
@@ -644,9 +651,6 @@ static bool movepln(OBJECTS *ob)
 		nearpln(ob);
 	}
 
-	deletex(ob);
-	insertx(ob, ob->ob_xnext);
-
 	if (ob->ob_bdelay) {
 		--ob->ob_bdelay;
 	}
@@ -698,8 +702,6 @@ bool moveshot(OBJECTS *ob)
 {
 	int x, y;
 
-	deletex(ob);
-	
 	--ob->ob_life;
 
 	if (ob->ob_life <= 0) {
@@ -715,7 +717,6 @@ bool moveshot(OBJECTS *ob)
 		return false;
 	}
 
-	insertx(ob, ob->ob_xnext);
 	ob->ob_newsym = &symbol_pixel;
 	return true;
 }
@@ -725,8 +726,7 @@ bool moveshot(OBJECTS *ob)
 bool movebomb(OBJECTS *ob)
 {
 	int x, y;
-
-	deletex(ob);
+	int ang;
 
 	if (ob->ob_life < 0) {
 		deallobj(ob);
@@ -749,8 +749,8 @@ bool movebomb(OBJECTS *ob)
 		return false;
 	}
 
-	ob->ob_newsym = symbol_bomb[symangle(ob)];
-	insertx(ob, ob->ob_xnext);
+	ang = symangle(ob);
+	ob->ob_newsym = &symbol_bomb[ang % 2]->sym[ang / 2];
 
 	if (y >= MAX_Y) {
 		return false;
@@ -766,8 +766,6 @@ bool movemiss(OBJECTS *ob)
 	int x, y, angle;
 	OBJECTS *obt;
 
-	deletex(ob);
-
 	if (ob->ob_life < 0) {
 		deallobj(ob);
 		ob->ob_state = FINISHED;
@@ -810,8 +808,8 @@ bool movemiss(OBJECTS *ob)
 		return false;
 	}
 
-	ob->ob_newsym = symbol_missile[ob->ob_angle];
-	insertx(ob, ob->ob_xnext);
+	ob->ob_newsym =
+		&symbol_missile[ob->ob_angle % 4]->sym[ob->ob_angle / 4];
 
 	if (y >= MAX_Y) {
 		return false;
@@ -826,7 +824,6 @@ bool moveburst(OBJECTS *ob)
 {
 	int x, y;
 
-	deletex(ob);
 	if (ob->ob_life < 0) {
 		ob->ob_owner->ob_missiletarget = NULL;
 		deallobj(ob);
@@ -843,33 +840,45 @@ bool moveburst(OBJECTS *ob)
 	}
 
 	ob->ob_owner->ob_missiletarget = ob;
-	ob->ob_newsym = symbol_burst[ob->ob_life & 1];
-	insertx(ob, ob->ob_xnext);
+	ob->ob_newsym = &symbol_burst[ob->ob_life & 1]->sym[0];
 
 	return y < MAX_Y;
 }
 
+static void target_enemy_planes(OBJECTS *ob)
+{
+	OBJECTS *obp;
+	int r;
 
-
+	// TODO: We can do better than scanning the entire object list.
+	for (obp = objtop; obp != NULL; obp = obp->ob_next) {
+		// Only shoot at enemy planes. In single player mode, computer
+		// planes do not get targeted.
+		if (obp->ob_type != PLANE || obp->ob_clr == ob->ob_clr ||
+		    (playmode != PLAYMODE_ASYNCH && obp != planes[0])) {
+			continue;
+		}
+		if (obp->ob_state != FLYING && obp->ob_state != STALLED
+		 && obp->ob_state != WOUNDED && obp->ob_state != WOUNDSTALL) {
+			continue;
+		}
+		r = range(ob->ob_x, ob->ob_y, obp->ob_x, obp->ob_y);
+		if (r > 0 && r < targrnge) {
+			initshot(ob, obp);
+			ob->ob_firing = obp;
+			break;
+		}
+	}
+}
 
 bool movetarg(OBJECTS *ob)
 {
-	int r;
-	OBJECTS *obp;
-
-	obp = objtop;
 	ob->ob_firing = NULL;
-	if (gamenum
-	 && ob->ob_state == STANDING
-	 && (obp->ob_state == FLYING
-	  || obp->ob_state == STALLED
-	  || obp->ob_state == WOUNDED
-	  || obp->ob_state == WOUNDSTALL)
-	 && ob->ob_clr != obp->ob_clr
-	 && (gamenum > 1 || (countmove & 0x0001))
-	 && ((r = range(ob->ob_x, ob->ob_y, obp->ob_x, obp->ob_y)) > 0)
-	 && r < targrnge) {
-		initshot(ob, ob->ob_firing = obp);
+
+	if (ob->ob_state == STANDING
+	 && gamenum > 0
+	 && (gamenum > 1 || (countmove & 0x0001))) {
+		target_enemy_planes(ob);
 	}
 
 	--ob->ob_hitcount;
@@ -879,9 +888,11 @@ bool movetarg(OBJECTS *ob)
 	}
 
 	if (ob->ob_state == STANDING) {
-		ob->ob_newsym = symbol_targets[ob->ob_orient];
+		int transform = ob->ob_original_ob->transform;
+		ob->ob_newsym =
+			&symbol_targets[ob->ob_orient]->sym[transform];
 	} else {
-		ob->ob_newsym = symbol_target_hit;
+		ob->ob_newsym = &symbol_target_hit->sym[0];
 	}
 
 	return true;
@@ -897,7 +908,6 @@ bool moveexpl(OBJECTS * obp)
 
 	ob = obp;
 	orient = ob->ob_orient;
-	deletex(ob);
 	if (ob->ob_life < 0) {
 		if (orient) {
 			stopsound(ob);
@@ -934,8 +944,7 @@ bool moveexpl(OBJECTS * obp)
 	}
 	++ob->ob_hitcount;
 
-	insertx(ob, ob->ob_xnext);
-	ob->ob_newsym = symbol_debris[ob->ob_orient];
+	ob->ob_newsym = &symbol_debris[ob->ob_orient]->sym[0];
 
 	return y < MAX_Y;
 }
@@ -972,7 +981,6 @@ bool moveflck(OBJECTS * obp)
 	int x, y;
 
 	ob = obp;
-	deletex(ob);
 
 	if (ob->ob_life == -1) {
 		deallobj(ob);
@@ -994,8 +1002,7 @@ bool moveflck(OBJECTS * obp)
 	}
 
 	movexy(ob, &x, &y);
-	insertx(ob, ob->ob_xnext);
-	ob->ob_newsym = symbol_flock[ob->ob_orient];
+	ob->ob_newsym = &symbol_flock[ob->ob_orient]->sym[0];
 	return true;
 }
 
@@ -1028,8 +1035,6 @@ bool movebird(OBJECTS * obp)
 
 	ob = obp;
 
-	deletex(ob);
-
 	if (ob->ob_life == -1) {
 		deallobj(ob);
 		return false;
@@ -1053,8 +1058,7 @@ bool movebird(OBJECTS * obp)
 
 	movexy(ob, &x, &y);
 
-	insertx(ob, ob->ob_xnext);
-	ob->ob_newsym = symbol_bird[ob->ob_orient];
+	ob->ob_newsym = &symbol_bird[ob->ob_orient]->sym[0];
 	if (x < 0 || x >= currgame->gm_max_x
 	 || y >= MAX_Y || y <= (int) ground[x]) {
 		ob->ob_y -= ob->ob_dy;
@@ -1069,7 +1073,8 @@ bool movebird(OBJECTS * obp)
 
 bool moveox(OBJECTS * ob)
 {
-	ob->ob_newsym = symbol_ox[ob->ob_state != STANDING];
+	int transform = ob->ob_original_ob->transform;
+	ob->ob_newsym = &symbol_ox[ob->ob_state != STANDING]->sym[transform];
 	return true;
 }
 
@@ -1112,51 +1117,6 @@ bool hitpln(OBJECTS * obp)
 	return true;
 }
 
-
-bool insertx(OBJECTS *ob, OBJECTS *obp)
-{
-	OBJECTS *obs;
-	int obx;
-
-	obs = obp;
-	obx = ob->ob_x;
-	if (obx < obs->ob_x) {
-		while (obs->ob_xprev != NULL && obx < obs->ob_xprev->ob_x) {
-			obs = obs->ob_xprev;
-		}
-		// Insert between obs->ob_xprev and obs:
-		ob->ob_xprev = obs->ob_xprev;
-		ob->ob_xnext = obs;
-	} else {
-		while (obs->ob_xnext != NULL && obx > obs->ob_xnext->ob_x) {
-			obs = obs->ob_xnext;
-		}
-		// Insert between obs and ob->ob_xnext:
-		ob->ob_xprev = obs;
-		ob->ob_xnext = obs->ob_xnext;
-	}
-	if (ob->ob_xprev != NULL) {
-		ob->ob_xprev->ob_xnext = ob;
-	}
-	if (ob->ob_xnext != NULL) {
-		ob->ob_xnext->ob_xprev = ob;
-	}
-
-	return true;
-}
-
-
-
-void deletex(OBJECTS *ob)
-{
-	if (ob->ob_xprev != NULL) {
-		ob->ob_xprev->ob_xnext = ob->ob_xnext;
-	}
-	if (ob->ob_xnext != NULL) {
-		ob->ob_xnext->ob_xprev = ob->ob_xprev;
-	}
-}
-
 //
 // 2003-02-14: Code was checked into version control; no further entries
 // will be added to this log.
