@@ -104,10 +104,10 @@ typedef struct yocton_prop yocton_prop;
  *   obj = yocton_read_with(read_callback, "foo: bar");
  * ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  *
- * @param callback   Callback function to invoke to read more data.
- * @param handle     Arbitrary pointer passed through when callback is
- *                   invoked.
- * @return           A @ref yocton_object representing the top-level object.
+ * @param callback  Callback function to invoke to read more data.
+ * @param handle    Arbitrary pointer passed through when callback is
+ *                  invoked.
+ * @return          A @ref yocton_object representing the top-level object.
  */
 struct yocton_object *yocton_read_with(yocton_read callback, void *handle);
 
@@ -123,8 +123,8 @@ struct yocton_object *yocton_read_with(yocton_read callback, void *handle);
  *   struct yocton_object *obj = yocton_read_from(fs);
  * ~~~~~~~~~~~~~~~~~~~~~~~
  *
- * @param fstream    File handle.
- * @return           A @ref yocton_object representing the top-level object.
+ * @param fstream  File handle.
+ * @return         A @ref yocton_object representing the top-level object.
  */
 struct yocton_object *yocton_read_from(FILE *fstream);
 
@@ -145,12 +145,12 @@ int yocton_have_error(struct yocton_object *obj, int *lineno,
                       const char **error_msg);
 
 /* Helper wrapper function around above, for array macros. */
-int __yocton_prop_have_error(struct yocton_prop *p);
+int __yocton_prop_have_error(struct yocton_prop *property);
 
 /**
  * Free the top-level object and stop reading from the input stream.
  *
- * @param obj        Top-level @ref yocton_object.
+ * @param obj  Top-level @ref yocton_object.
  */
 void yocton_free(struct yocton_object *obj);
 
@@ -193,10 +193,10 @@ struct yocton_prop *yocton_next_prop(struct yocton_object *obj);
  *
  * See @ref yocton_next_prop for an example of how this might be used.
  *
- * @param p  The property.
- * @return   Type of the property.
+ * @param property  The property.
+ * @return          Type of the property.
  */
-enum yocton_prop_type yocton_prop_type(struct yocton_prop *p);
+enum yocton_prop_type yocton_prop_type(struct yocton_prop *property);
 
 /**
  * Get the name of a @ref yocton_prop. Multiple properties of the same object
@@ -205,11 +205,11 @@ enum yocton_prop_type yocton_prop_type(struct yocton_prop *p);
  *
  * See @ref yocton_next_prop for an example of how this might be used.
  *
- * @param p  The property.
- * @return   Name of the property. The returned string is only valid for the
- *           lifetime of the property itself.
+ * @param property  The property.
+ * @return          Name of the property. The returned string is only valid
+ *                  for the lifetime of the property itself.
  */
-const char *yocton_prop_name(struct yocton_prop *p);
+const char *yocton_prop_name(struct yocton_prop *property);
 
 /**
  * Get the string value of a @ref yocton_prop of type
@@ -218,12 +218,13 @@ const char *yocton_prop_name(struct yocton_prop *p);
  *
  * See @ref yocton_next_prop for an example of how this might be used.
  *
- * @param p  The property.
- * @return   String value of this property, or NULL if it is not a property of
- *           type @ref YOCTON_PROP_STRING. The returned string is only
- *           valid for the lifetime of the property itself.
+ * @param property  The property.
+ * @return          String value of this property, or NULL if it is not a
+ *                  property of type @ref YOCTON_PROP_STRING. The returned
+ *                  string is only valid for the lifetime of the property
+ *                  itself.
  */
-const char *yocton_prop_value(struct yocton_prop *p);
+const char *yocton_prop_value(struct yocton_prop *property);
 
 /**
  * Get newly-allocated copy of a property value.
@@ -239,23 +240,23 @@ const char *yocton_prop_value(struct yocton_prop *p);
  * It may be more convenient to use @ref YOCTON_VAR_STRING which is a wrapper
  * around this function.
  *
- * @param p  The property.
- * @return   String value of this property, or NULL if it is not a property of
- *           type @ref YOCTON_PROP_STRING, or if a memory allocation failure
- *           occurred.
+ * @param property  The property.
+ * @return          String value of this property, or NULL if it is not a
+ *                  property of type @ref YOCTON_PROP_STRING, or if a memory
+ *                  allocation failure occurred.
  */
-char *yocton_prop_value_dup(struct yocton_prop *p);
+char *yocton_prop_value_dup(struct yocton_prop *property);
 
 /**
  * Match a particular property name.
  *
- * @param property     The property.
- * @param name         Name of property to match.
- * @param then         Code to execute if yocton_prop_name(property) == name.
+ * @param property  The property.
+ * @param name      Name of property to match.
+ * @param then      Code to execute if yocton_prop_name(property) == name.
  */
 #define YOCTON_IF_PROP(property, name, then) \
 	do { \
-		if (!strcmp(yocton_prop_name(property), #name)) { \
+		if (!strcmp(yocton_prop_name(property), name)) { \
 			then \
 		} \
 	} while (0)
@@ -264,12 +265,15 @@ char *yocton_prop_value_dup(struct yocton_prop *p);
 int __yocton_reserve_array(struct yocton_prop *p, void **array,
                            size_t nmemb, size_t size);
 
+/* Helper function used by YOCTON_VAR_PTR() */
+int __yocton_prop_alloc(struct yocton_prop *p, void **ptr, size_t size);
+
 /**
  * Match a particular property name and allocate array storage.
  *
  * This macro is used to build other array macros such as
  * @ref YOCTON_VAR_INT_ARRAY and @ref YOCTON_VAR_STRING_ARRAY. If the
- * name of the given property is equal to `propname`, the variable `varname`
+ * name of the given property is equal to `propname`, the variable `var`
  * (a pointer to array data) will be reallocated so that enough space is
  * available in the array to append a new element. The argument `then` is then
  * evaluated to (conditionally) append the new element.
@@ -282,24 +286,24 @@ int __yocton_reserve_array(struct yocton_prop *p, void **array,
  *   struct yocton_prop *p;
  *
  *   while ((p = yocton_next_prop(obj)) != NULL) {
- *       YOCTON_VAR_ARRAY(p, foo, elements, num_elements, {
+ *       YOCTON_VAR_ARRAY(p, "foo", elements, num_elements, {
  *           elements[num_elements].id = yocton_prop_int(p, sizeof(int));
  *           num_elements++;
  *       });
  *   }
  * ~~~~~~~~~~~~~~~~~~~~~~~
  *
- * @param prop         The property.
- * @param propname     The property name to match.
- * @param varname      Name of the variable pointing to array data.
- * @param varname_len  Variable storing length of array.
- * @param then         Code to evaluate after new element space is allocated.
+ * @param property  The property.
+ * @param propname  The property name to match.
+ * @param var       Variable pointing to array data.
+ * @param len_var   Variable storing length of array.
+ * @param then      Code to evaluate after new element space is allocated.
  */
-#define YOCTON_VAR_ARRAY(prop, propname, varname, varname_len, then) \
-	YOCTON_IF_PROP(prop, propname, { \
-		if (__yocton_reserve_array(prop, (void **) &(varname), \
-		                           varname_len, \
-		                           sizeof(*(varname)))) { \
+#define YOCTON_VAR_ARRAY(property, propname, var, len_var, then) \
+	YOCTON_IF_PROP(property, propname, { \
+		if (__yocton_reserve_array(property, (void **) &(var), \
+		                           len_var, \
+		                           sizeof(*(var)))) { \
 			then \
 		} \
 	})
@@ -307,9 +311,9 @@ int __yocton_reserve_array(struct yocton_prop *p, void **array,
 /**
  * Set the value of a string variable if appropriate.
  *
- * If the name of the property currently being parsed is equal to `propname`,
- * the variable `varname` will be initialized to a newly-allocated buffer
- * containing a copy of the string value.
+ * If the name of `property` is equal to `propname`, the variable `var`
+ * will be initialized to a newly-allocated buffer containing a copy of the
+ * string value.
  *
  * If the variable has an existing value it will be freed. It is therefore
  * important that the variable is initialized to NULL before the first time
@@ -317,53 +321,58 @@ int __yocton_reserve_array(struct yocton_prop *p, void **array,
  *
  * Example to match a property named "foo":
  * ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+ *   // Example of data being parsed:
+ *   //   foo: "first value"
+ *   //   foo: "replacement value"
  *   char *bar = NULL;
  *   struct yocton_prop *p;
  *
  *   while ((p = yocton_next_prop(obj)) != NULL) {
- *       YOCTON_VAR_STRING(p, foo, bar);
+ *       YOCTON_VAR_STRING(p, "foo", bar);
  *   }
  * ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  *
- * @param prop       Property.
- * @param propname   Name of property to match.
- * @param varname    Name of variable to initialize.
+ * @param property  Property.
+ * @param propname  Name of property to match.
+ * @param var       Variable to initialize.
  */
-#define YOCTON_VAR_STRING(prop, propname, varname) \
-	YOCTON_IF_PROP(prop, propname, { \
-		free(varname); \
-		varname = yocton_prop_value_dup(prop); \
+#define YOCTON_VAR_STRING(property, propname, var) \
+	YOCTON_IF_PROP(property, propname, { \
+		free(var); \
+		var = yocton_prop_value_dup(property); \
 	})
 
 /**
  * Append value to a string array if appropriate.
  *
- * If the name of the property currently being parsed is equal to `propname`,
- * the property value will be appended to the string array pointed at by
- * `varname`.
+ * If the name of `property` is equal to `propname`, the property value will be
+ * appended to the string array pointed at by `var`.
  *
  * Example to populate an array "bar" from a property named "foo":
  * ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+ *   // Example of data being parsed:
+ *   //   foo: "first string"
+ *   //   foo: "second string"
  *   char **bar = NULL;
  *   size_t bar_len = 0;
  *   struct yocton_prop *p;
  *
  *   while ((p = yocton_next_prop(obj)) != NULL) {
- *       YOCTON_VAR_STRING_ARRAY(p, foo, bar, bar_len);
+ *       YOCTON_VAR_STRING_ARRAY(p, "foo", bar, bar_len);
  *   }
  * ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  *
- * @param prop         Property.
- * @param propname     Name of property to match.
- * @param varname      Name of variable pointing to array data.
- * @param varname_len  Name of variable containing length of array.
+ * @param property  Property.
+ * @param propname  Name of property to match.
+ * @param var       Variable pointing to array data.
+ * @param len_var   Variable containing length of array.
  */
-#define YOCTON_VAR_STRING_ARRAY(prop, propname, varname, varname_len) \
-	YOCTON_VAR_ARRAY(prop, propname, varname, varname_len, { \
-		char *__v = yocton_prop_value_dup(prop); \
+#define YOCTON_VAR_STRING_ARRAY(property, propname, var, len_var) \
+	YOCTON_VAR_ARRAY(property, propname, var, len_var, { \
+		char *__v = yocton_prop_value_dup(property); \
 		if (__v) { \
-			(varname)[varname_len] = __v; \
-			++(varname_len); \
+			(var)[len_var] = __v; \
+			++(len_var); \
 		} \
 	})
 
@@ -385,12 +394,12 @@ int __yocton_reserve_array(struct yocton_prop *p, void **array,
  *   }
  * ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  *
- * @param p  The property.
- * @return   Inner @ref yocton_object, or NULL if the property is not of type
- *           @ref YOCTON_PROP_OBJECT. The returned object is only only
- *           valid for the lifetime of the property itself.
+ * @param property  The property.
+ * @return          Inner @ref yocton_object, or NULL if the property is not
+ *                  of type @ref YOCTON_PROP_OBJECT. The returned object is
+ *                  only valid for the lifetime of the property itself.
  */
-struct yocton_object *yocton_prop_inner(struct yocton_prop *p);
+struct yocton_object *yocton_prop_inner(struct yocton_prop *property);
 
 /**
  * Parse the property value as a signed integer.
@@ -401,76 +410,84 @@ struct yocton_object *yocton_prop_inner(struct yocton_prop *p);
  * It may be more convenient to use @ref YOCTON_VAR_INT which is a wrapper
  * around this function.
  *
- * @param p   The property.
- * @param n   Size of the expected property in bytes, eg. sizeof(uint16_t).
- * @return    The integer value, or zero if it cannot be parsed as an
- *            integer of that size. Although the return value is a long
- *            long type, it will always be in the range of an integer
- *            of the given size and can be safely cast to one.
+ * @param property  The property.
+ * @param n         Size of the expected property in bytes,
+ *                  eg. sizeof(uint16_t).
+ * @return          The integer value, or zero if it cannot be parsed as an
+ *                  integer of that size. Although the return value is a long
+ *                  long type, it will always be in the range of an integer
+ *                  of the given size and can be safely cast to one.
  */
-signed long long yocton_prop_int(struct yocton_prop *p, size_t n);
+signed long long yocton_prop_int(struct yocton_prop *property, size_t n);
 
 /**
  * Set the value of a signed integer variable if appropriate.
  *
- * If the name of the property currently being parsed has is equal to
- * `propname`, the variable `varname` will be initialized to a signed integer
- * value parsed from the property value. If the property value cannot be parsed
- * as a signed integer, the variable will be set to zero and an error set.
+ * If the name of `property` is equal to `propname`, the variable `var`
+ * will be initialized to a signed integer value parsed from the property
+ * value. If the property value cannot be parsed as a signed integer, the
+ * variable will be set to zero and an error set.
  *
  * This will work with any kind of signed integer variable, but the type of the
  * variable must be provided.
  *
  * Example to match a property named "foo":
  * ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+ *   // Example of data being parsed:
+ *   //   foo: -1234
  *   int bar;
  *   struct yocton_prop *p;
  *
  *   while ((p = yocton_next_prop(obj)) != NULL) {
- *       YOCTON_VAR_INT(p, foo, int, bar);
+ *       YOCTON_VAR_INT(p, "foo", int, bar);
  *   }
  * ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  *
- * @param prop         Property.
- * @param propname     Name of the property to match.
- * @param var_type     Type of the variable, eg. `int` or `ssize_t`.
- * @param varname      Name of variable to set.
+ * @param property  Property.
+ * @param propname  Name of the property to match.
+ * @param var_type  Type of the variable, eg. `int` or `ssize_t`.
+ * @param var       Variable to set.
  */
-#define YOCTON_VAR_INT(prop, propname, var_type, varname) \
-	YOCTON_IF_PROP(prop, propname, { \
-		varname = (var_type) yocton_prop_int(prop, sizeof(var_type)); \
+#define YOCTON_VAR_INT(property, propname, var_type, var) \
+	YOCTON_IF_PROP(property, propname, { \
+		var = (var_type) yocton_prop_int(property, \
+		                                 sizeof(var_type)); \
 	})
 
 /**
  * Append value to an array of signed integers if appropriate.
  *
- * If the name of the property currently being parsed is equal to `propname`,
- * the property value will be parsed as a signed integer and appended to the
- * array pointed at by `varname`.
+ * If the name of `property` is equal to `propname`, the property value will be
+ * parsed as a signed integer and appended to the array pointed at by
+ * `var`.
  *
  * Example to populate an array "bar" from a property named "foo":
  * ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+ *   // Example of data being parsed:
+ *   //   foo: 1234
+ *   //   foo: "5678"
+ *   //   foo: -9999
  *   int *bar = NULL;
  *   size_t bar_len = 0;
  *   struct yocton_prop *p;
  *
  *   while ((p = yocton_next_prop(obj)) != NULL) {
- *       YOCTON_VAR_INT_ARRAY(p, foo, int, bar, bar_len);
+ *       YOCTON_VAR_INT_ARRAY(p, "foo", int, bar, bar_len);
  *   }
  * ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  *
- * @param prop         Property.
- * @param propname     Name of property to match.
- * @param var_type     Type of array element.
- * @param varname      Name of variable pointing to array data.
- * @param varname_len  Name of variable containing length of array.
+ * @param property  Property.
+ * @param propname  Name of property to match.
+ * @param var_type  Type of array element.
+ * @param var       Variable pointing to array data.
+ * @param len_var   Variable containing length of array.
  */
-#define YOCTON_VAR_INT_ARRAY(prop, propname, var_type, varname, varname_len) \
-	YOCTON_VAR_ARRAY(prop, propname, varname, varname_len, { \
-		(varname)[varname_len] = (var_type) \
-			yocton_prop_int(prop, sizeof(var_type)); \
-		if (!__yocton_prop_have_error(prop)) { \
-			++(varname_len); \
+#define YOCTON_VAR_INT_ARRAY(property, propname, var_type, var, len_var) \
+	YOCTON_VAR_ARRAY(property, propname, var, len_var, { \
+		(var)[len_var] = (var_type) \
+			yocton_prop_int(property, sizeof(var_type)); \
+		if (!__yocton_prop_have_error(property)) { \
+			++(len_var); \
 		} \
 	})
 
@@ -483,77 +500,84 @@ signed long long yocton_prop_int(struct yocton_prop *p, size_t n);
  * It may be more convenient to use @ref YOCTON_VAR_UINT which is a wrapper
  * around this function.
  *
- * @param p   The property.
- * @param n   Size of the expected property in bytes, eg. sizeof(uint16_t).
- * @return    The integer value, or zero if it cannot be parsed as an
- *            signed integer of that size. Although the return value is a
- *            long long type, it will always be in the range of an integer
- *            of the given size and can be safely cast to one.
+ * @param property  The property.
+ * @param n         Size of the expected property in bytes,
+ *                  eg. sizeof(uint16_t).
+ * @return          The integer value, or zero if it cannot be parsed as an
+ *                  signed integer of that size. Although the return value is
+ *                  a long long type, it will always be in the range of an
+ *                  integer of the given size and can be safely cast to one.
  */
-unsigned long long yocton_prop_uint(struct yocton_prop *p, size_t n);
+unsigned long long yocton_prop_uint(struct yocton_prop *property, size_t n);
 
 /**
  * Set the value of an unsigned integer variable if appropriate.
  *
- * If the name of the property currently being parsed has is equal to
- * `propname`, the variable `varname` will be initialized to an unsigned integer
- * value parsed from the property value. If the property value cannot be parsed
- * as an unsigned integer, the variable will be set to zero and an error set.
+ * If the name of `property` is equal to `propname`, the variable `var`
+ * will be initialized to an unsigned integer value parsed from the property
+ * value. If the property value cannot be parsed as an unsigned integer, the
+ * variable will be set to zero and an error set.
  *
  * This will work with any kind of unssigned integer variable, but the type of
  * the variable must be provided.
  *
  * Example to match a property named "foo":
  * ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+ *   // Example of data being parsed:
+ *   //   foo: 12345
  *   unsigned int bar;
  *   struct yocton_prop *p;
  *
  *   while ((p = yocton_next_prop(obj)) != NULL) {
- *       YOCTON_VAR_UINT(p, foo, unsigned int, bar);
+ *       YOCTON_VAR_UINT(p, "foo", unsigned int, bar);
  *   }
  * ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  *
- * @param prop         Property.
- * @param propname     Name of the property to match.
- * @param var_type     Type of the variable, eg. `uint32_t` or `size_t`.
- * @param varname      Name of variable to set.
+ * @param property  Property.
+ * @param propname  Name of the property to match.
+ * @param var_type  Type of the variable, eg. `uint32_t` or `size_t`.
+ * @param var       Variable to set.
  */
-#define YOCTON_VAR_UINT(prop, propname, var_type, varname) \
-	YOCTON_IF_PROP(prop, propname, { \
-		varname = (var_type) \
-			yocton_prop_uint(prop, sizeof(var_type)); \
+#define YOCTON_VAR_UINT(property, propname, var_type, var) \
+	YOCTON_IF_PROP(property, propname, { \
+		var = (var_type) \
+			yocton_prop_uint(property, sizeof(var_type)); \
 	})
 
 /**
  * Append value to an array of unsigned integers if appropriate.
  *
- * If the name of the property currently being parsed is equal to `propname`,
- * the property value will be parsed as an unsigned integer and appended to the
- * array pointed at by `varname`.
+ * If the name of `property` is equal to `propname`, the property value will be
+ * parsed as an unsigned integer and appended to the array pointed at by
+ * `var`.
  *
  * Example to populate an array "bar" from a property named "foo":
  * ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+ *   // Example of data being parsed:
+ *   //   foo: 123
+ *   //   foo: "456"
+ *   //   foo: 789
  *   unsigned int *bar = NULL;
  *   size_t bar_len = 0;
  *   struct yocton_prop *p;
  *
  *   while ((p = yocton_next_prop(obj)) != NULL) {
- *       YOCTON_VAR_UINT_ARRAY(p, foo, unsigned int, bar, bar_len);
+ *       YOCTON_VAR_UINT_ARRAY(p, "foo", unsigned int, bar, bar_len);
  *   }
  * ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  *
- * @param prop         Property.
- * @param propname     Name of property to match.
- * @param var_type     Type of array element.
- * @param varname      Name of variable pointing to array data.
- * @param varname_len  Name of variable containing length of array.
+ * @param property  Property.
+ * @param propname  Name of property to match.
+ * @param var_type  Type of array element.
+ * @param var       Variable pointing to array data.
+ * @param len_var   Variable containing length of array.
  */
-#define YOCTON_VAR_UINT_ARRAY(prop, propname, var_type, varname, varname_len) \
-	YOCTON_VAR_ARRAY(prop, propname, varname, varname_len, { \
-		(varname)[varname_len] = (var_type) \
-			yocton_prop_uint(prop, sizeof(var_type)); \
-		if (!__yocton_prop_have_error(prop)) { \
-			++(varname_len); \
+#define YOCTON_VAR_UINT_ARRAY(property, propname, var_type, var, len_var) \
+	YOCTON_VAR_ARRAY(property, propname, var, len_var, { \
+		(var)[len_var] = (var_type) \
+			yocton_prop_uint(property, sizeof(var_type)); \
+		if (!__yocton_prop_have_error(property)) { \
+			++(len_var); \
 		} \
 	})
 
@@ -571,75 +595,173 @@ unsigned long long yocton_prop_uint(struct yocton_prop *p, size_t n);
  * It may be more convenient to use @ref YOCTON_VAR_ENUM which is a wrapper
  * around this function.
  *
- * @param p       The property.
- * @param values  Pointer to a NULL-terminated array of strings representing
- *                enum values. values[e] is a string representing enum
- *                value e.
- * @return        The identified enum value. If not found, an error is set
- *                and zero is returned.
+ * @param property  The property.
+ * @param values    Pointer to a NULL-terminated array of strings representing
+ *                  enum values. values[e] is a string representing enum
+ *                  value e.
+ * @return          The identified enum value. If not found, an error is set
+ *                  and zero is returned.
  */
-unsigned int yocton_prop_enum(struct yocton_prop *p, const char **values);
+unsigned int yocton_prop_enum(struct yocton_prop *property, const char **values);
 
 /**
  * Set the value of an enum variable if appropriate.
  *
- * If the name of the property currently being parsed is equal to `propname`,
- * the variable `varname` will be initialized to an enum value that matches a
- * name from the given list.
+ * If the name of `property` is equal to `propname`, the variable `var`
+ * will be initialized to an enum value that matches a name from the given
+ * list.
  *
  * Example to match a property named "foo":
  * ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+ *   // Example of data to be parsed:
+ *   //   foo: SECOND
  *   const char *enum_values[] = {"FIRST", "SECOND", "THIRD", NULL};
  *   int bar;
  *   struct yocton_prop *p;
  *
  *   while ((p = yocton_next_prop(obj)) != NULL) {
- *       YOCTON_VAR_ENUM(p, foo, bar, enum_values);
+ *       YOCTON_VAR_ENUM(p, "foo", bar, enum_values);
  *   }
  * ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  *
- * @param prop       Property.
- * @param propname   Name of the property to match.
- * @param varname    Name of variable to initialize.
- * @param values     NULL-terminated array of strings representing enum values
- *                   (same as values parameter to @ref yocton_prop_enum).
+ * @param property  Property.
+ * @param propname  Name of the property to match.
+ * @param var       Variable to initialize.
+ * @param values    NULL-terminated array of strings representing enum values
+ *                  (same as values parameter to @ref yocton_prop_enum).
  */
-#define YOCTON_VAR_ENUM(prop, propname, varname, values) \
-	YOCTON_IF_PROP(prop, propname, { \
-		(varname) = yocton_prop_enum(prop, values); \
+#define YOCTON_VAR_ENUM(property, propname, var, values) \
+	YOCTON_IF_PROP(property, propname, { \
+		(var) = yocton_prop_enum(property, values); \
 	})
 
 /**
  * Append value to an array of enums if appropriate.
  *
- * If the name of the property currently being parsed is equal to `propname`,
- * the property value will be parsed as an enum and then appended to the array
- * pointed at by `varname`.
+ * If the name of `property` is equal to `propname`, the property value will be
+ * parsed as an enum and then appended to the array pointed at by `var`.
  *
  * Example to populate an array "bar" from a property named "foo":
  * ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+ *   // Example of data to be parsed:
+ *   //   foo: FIRST
+ *   //   foo: "SECOND"
+ *   //   foo: FIRST
  *   const char *enum_names[] = {"FIRST", "SECOND", "THIRD", NULL};
  *   int *bar = NULL;
  *   size_t bar_len = 0;
  *   struct yocton_prop *p;
  *
  *   while ((p = yocton_next_prop(obj)) != NULL) {
- *       YOCTON_VAR_ENUM_ARRAY(p, foo, bar, bar_len, enum_names);
+ *       YOCTON_VAR_ENUM_ARRAY(p, "foo", bar, bar_len, enum_names);
  *   }
  * ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  *
- * @param prop         Property.
- * @param propname     Name of property to match.
- * @param varname      Name of variable pointing to array data.
- * @param varname_len  Name of variable containing length of array.
- * @param values       NULL-terminated array of strings representing enum values
- *                     (same as values parameter to @ref yocton_prop_enum).
+ * @param property  Property.
+ * @param propname  Name of property to match.
+ * @param var       Variable pointing to array data.
+ * @param len_var   Variable containing length of array.
+ * @param values    NULL-terminated array of strings representing enum values
+ *                  (same as values parameter to @ref yocton_prop_enum).
  */
-#define YOCTON_VAR_ENUM_ARRAY(prop, propname, varname, varname_len, values) \
-	YOCTON_VAR_ARRAY(prop, propname, varname, varname_len, { \
-		(varname)[varname_len] = yocton_prop_enum(prop, values); \
-		if (!__yocton_prop_have_error(prop)) { \
-			++(varname_len); \
+#define YOCTON_VAR_ENUM_ARRAY(property, propname, var, len_var, values) \
+	YOCTON_VAR_ARRAY(property, propname, var, len_var, { \
+		(var)[len_var] = yocton_prop_enum(property, values); \
+		if (!__yocton_prop_have_error(property)) { \
+			++(len_var); \
+		} \
+	})
+
+/**
+ * Allocate memory and set pointer variable if appropriate.
+ *
+ * If the name of `property` is equal to `propname`, the pointer variable
+ * `var` will be initialized to a newly allocated block of
+ * `sizeof(*var)` bytes.
+ *
+ * The pointer variable must be equal to NULL; if it is not, an error will
+ * be set. This usually means that the property must be unique in the input.
+ * This is to prevent a memory leak if the pointer is allocated twice.
+ *
+ * Example to match a property named "foo":
+ * ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+ *   // Example of data to be parsed:
+ *   //   coordinate {
+ *   //     x: 123
+ *   //     y: 123
+ *   //   }
+ *   struct coord *ptr = NULL;
+ *   struct yocton_prop *p;
+ *
+ *   while ((p = yocton_next_prop(obj)) != NULL) {
+ *       YOCTON_VAR_PTR(p, "coordinate", ptr, {
+ *           parse_coord(yocton_prop_inner(p), ptr);
+ *       });
+ *   }
+ * ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+ *
+ * @param property  Property.
+ * @param propname  Name of the property to match.
+ * @param var       Pointer variable to initialize.
+ * @param then      Block of code to execute if the property is matched.
+ */
+#define YOCTON_VAR_PTR(property, propname, var, then) \
+	YOCTON_IF_PROP(property, propname, { \
+		if (__yocton_prop_alloc(property, (void **) &(var), \
+		                        sizeof(*(var)))) { \
+			then \
+		} \
+	})
+
+/**
+ * Allocate memory and append pointer to it to an array if appropriate.
+ *
+ * If the name of `property` is equal to `propname`,
+ * a newly allocated block of `sizeof(**var)` bytes will be allocated, and
+ * appended to the array `var`.
+ *
+ * The code in the `then` block should initialize the new memory pointed at by
+ * `var[len_var]`, and then increment `len_var`. If `len_var`
+ * is not incremented, the memory block that was allocated will be freed, the
+ * assumption being that it was not needed after all.
+ *
+ * Example that matches a property named "foo" to populate an array of struct
+ * pointers:
+ * ~~~~~~~~~~~~~~~~~~~~~~~
+ *   // Example of data to be parsed:
+ *   //   coordinate { x: 123 y:456 }
+ *   //   coordinate { x: 999 y:789 }
+ *   //   coordinate { x: 555 y:127 }
+ *   struct coord **coords = NULL;
+ *   size_t num_coords;
+ *   struct yocton_prop *p;
+ *
+ *   while ((p = yocton_next_prop(obj)) != NULL) {
+ *       YOCTON_VAR_PTR_ARRAY(p, "coordinate", coords, num_coords, {
+ *           parse_coord(yocton_prop_inner(obj), coords[num_coords]);
+ *           num_coords++;
+ *       });
+ *   }
+ * ~~~~~~~~~~~~~~~~~~~~~~~
+ *
+ * @param property  The property.
+ * @param propname  The property name to match.
+ * @param var       Variable pointing to array of pointers.
+ * @param len_var   Variable storing length of array.
+ * @param then      Code to evaluate after new property is matched.
+ */
+#define YOCTON_VAR_PTR_ARRAY(property, propname, var, len_var, then) \
+	YOCTON_VAR_ARRAY(property, propname, var, len_var, { \
+		(var)[len_var] = NULL; \
+		if (__yocton_prop_alloc(property, \
+		                        (void **) &((var)[len_var]), \
+		                        sizeof(**(var)))) { \
+			long old_len = len_var; \
+			then \
+			if ((len_var) == old_len) { \
+				free(var); \
+				(var)[len_var] = NULL; \
+			} \
 		} \
 	})
 
